@@ -6,32 +6,13 @@
 #
 # Distributed under terms of the Expat license.
 
-"""
-
-"""
-
 
 from pysol_cards.cards import ms_rearrange
+from pysol_cards.random_base import RandomBase
 
 import random2
 
 
-class RandomBase(object):
-    DEALS_PYSOL = 0
-    DEALS_PYSOLFC = 1
-    DEALS_MS = 2
-
-    def shuffle(self, seq):
-        for n in range(len(seq) - 1, 0, -1):
-            j = self.randint(0, n)
-            seq[n], seq[j] = seq[j], seq[n]
-        return seq
-
-    def randint(self, a, b):
-        """ Get a random integer in the range [a, b] including both ends."""
-        return a + int(self.random() * (b + 1 - a))
-
-
 class PysolRandom(RandomBase):
     def setSeed(self, seed):
         seed = self._convertSeed(seed)
